PALM-meteo: palmmeteo.library.LatLonRegularGrid Class Reference

PALM-meteo

Public Member Functions | Public Attributes | List of all members
palmmeteo.library.LatLonRegularGrid Class Reference

## Public Member Functions
def | __init__ (self, lats, lons)

## Public Attributes
| latlon_to_ji
| ji_to_latlon

## Detailed Description

    Coordinate transformer for simple regular lat-lon grids

## Constructor & Destructor Documentation

## ◆ __init__()

def palmmeteo.library.LatLonRegularGrid.__init__ | ( |  | self,
|  |  | lats,
|  |  | lons
| ) |  |

## Member Data Documentation

## ◆ ji_to_latlon

palmmeteo.library.LatLonRegularGrid.ji_to_latlon

## ◆ latlon_to_ji

palmmeteo.library.LatLonRegularGrid.latlon_to_ji

The documentation for this class was generated from the following file:

- palmmeteo/library.py